[![KendoReact NPM Banner](https://raw.githubusercontent.com/telerik/kendo-react/master/images/kendoreact-github-banner.png)](https://www.telerik.com/kendo-react-ui/components/free?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common&utm_content=banner)

# KendoReact Common Library for React

> **Important**
>
> -   This package is а part of [KendoReact](https://www.telerik.com/kendo-react-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common)&mdash;an enterprise-grade UI library with 120+ free and premium components.
> -   It contains both free and premium KendoReact components and tools. To use the premium components, you will need to [purchase a license](https://www.telerik.com/kendo-react-ui/pricing?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common) or register for a [free trial](https://www.telerik.com/try/kendo-react-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common). You can use the free components without having to sign up or get a license key.
> -   If you're looking for free React components, check out [Get Started with KendoReact Free](https://www.telerik.com/kendo-react-ui/components/free).
> -   If you have an active license, visit the [KendoReact My License page](https://www.telerik.com/kendo-react-ui/components/my-license/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common) to learn how to configure your KendoReact licensing.
> -   Installing and working with this package indicates that you [accept the KendoReact License Agreement](https://www.telerik.com/purchase/license-agreement/progress-kendoreact?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common).
> -   The 30-day free trial gives you access to all KendoReact components and their full functionality. Additionally, for the period of your trial, you can use our legendary technical support provided directly by the KendoReact dev team!
>
> [Start using KendoReact](https://www.telerik.com/try/kendo-react-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common) and speed up your development process!

The React Common package, part of KendoReact, delivers common utilities that can be used with the KendoReact UI components to enhance their performance and functionality.

How to start:

```sh
npm i @progress/kendo-react-common
```

What's in this package:

-   [React Draggable component (premium)](#react-draggable-component)
-   [React Icon component (free)](#react-icon-component)
-   [React SvgIcon component (free)](#react-svgicon-component)
-   [React Typography component (free)](#react-typography-component)
-   [React AdaptiveModeContext (free)](#react-typography-component)

Additional information:

-   [Support Options](#support-options)
-   [Resources](#resources)
-   [KendoReact Common API](https://www.telerik.com/kendo-react-ui/components/common/api)

## React Draggable Component

> This is a KendoReact **premium component** and requires a commercial license or an active trial license.

[The KendoReact Draggable component](https://www.telerik.com/kendo-react-ui/components/common/drag-and-drop?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common) enables the drag-and-drop functionality with which the user can drag and drop component elements.

How to use the Draggable component in your apps:

```tsx
import { DragAndDrop, useDroppable, NormalizedDragEvent } from '@progress/kendo-react-common';
...
<DragAndDrop>
    /**
    * Handle drag-and-drop logic and containers.
    */
</DragAndDrop>
```

## React Icon Component

> This is a **free React component**&mdash;no sign-up or license required.

[The KendoReact Icon component](https://www.telerik.com/kendo-react-ui/components/utils/icon/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common) is used to display font icons to ensure React developers can use icons in any scenario. [All Kendo UI Icons](https://www.telerik.com/kendo-react-ui/components/styling/icons/#list-of-font-icons/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common) are supported.

How to use the Icon component in your apps:

```tsx
import { Icon } from '@progress/kendo-react-common';
...
<link rel="stylesheet" href="https://unpkg.com/@progress/kendo-font-icons/dist/index.css" />
<Icon name="home"/>
```

## React SvgIcon Component

> This is a **free React component**&mdash;no sign-up or license required.

[The KendoReact SvgIcon component](https://www.telerik.com/kendo-react-ui/components/utils/svgicon/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common) is used to display SVG icons. KendoReact delivers more than 500 SVG icons. The size, color and orientation of the KendoReact SvgIcon component can be easily customized through the available properties.

How to use the SvgIcon component in your apps:

```tsx
import { SvgIcon } from '@progress/kendo-react-common';
import { homeIcon } from '@progress/kendo-svg-icons'; // This dependency is not automatically installed.
...
<SvgIcon icon={homeIcon} />
```

## React Typography Component

> This is a **free React component**&mdash;no sign-up or license required.

[The KendoReact Typography component](https://www.telerik.com/kendo-react-ui/components/utils/typography/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common) is a reusable component that helps presenting text in a React application. It could trim down a lot of time as the application grows. You can quickly add additional Typography styles by choosing from the predefined options.

How to use the SvgIcon component in your apps:

```tsx
import { Typography } from '@progress/kendo-react-common';
...
<Typography.p>
    Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec semper.
</Typography.p>
```

## React AdaptiveModeContext

> This is a **free React utility**&mdash;no sign-up or license required.

[The KendoReact AdaptiveModeContext utility](https://www.telerik.com/kendo-react-ui/components/common/adaptive-mode?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common) is a React context that provides a global configuration for adaptive rendering across various components. It lets you define breakpoints for small and medium screen sizes. This context is essential for implementing responsive layouts, where UI components such as DatePicker, DropDownList, ComboBox, and others may need to adapt.

How to use AdaptiveModeContext in your apps:

```tsx
import { AdaptiveModeContext } from '@progress/kendo-react-common';
...
<AdaptiveModeContext.Provider value={{ small: 320, medium: 1024 }}>
    /**
    * Place the UI component that needs to be adaptive here.
    */
</AdaptiveModeContext.Provider>
```

## Support Options

For any issues you might encounter while working with the KendoReact Common package, use any of the available support channels:

-   Industry-leading technical support&mdash;KendoReact paid license holders and users with an active (free) trial license can take advantage of our outstanding customer support. To submit a ticket, use [the dedicated KendoReact support system](https://www.telerik.com/account/support-center/contact-us/technical-support?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common).
-   Product forums&mdash;The [KendoReact forums](https://www.telerik.com/forums/kendo-ui-react?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common) are part of the free support you can get from the community and from the KendoReact team.
-   Feedback portal&mdash;The [KendoReact feedback portal](https://feedback.telerik.com/kendo-react-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common) is where you can request and vote for new features to be added.

## Resources

General resources:

-   [Getting Started with KendoReact](https://www.telerik.com/kendo-react-ui/components/getting-started/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common)
-   [Get Started with KendoReact Free](https://www.telerik.com/kendo-react-ui/components/free)
-   [KendoReact Roadmap](https://www.telerik.com/kendo-react-ui/roadmap/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common)
-   [Blogs](https://www.telerik.com/blogs/tag/kendoreact?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common)
-   [Demos, documentation, and component reference](https://www.telerik.com/kendo-react-ui/components/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common)
-   [KendoReact pricing and licensing](https://www.telerik.com/kendo-react-ui/pricing?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common)
-   [Changelog](https://www.telerik.com/kendo-react-ui/components/changelogs/ui-for-react/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-common)

High-level component overview pages:

-   [React Drag & Drop Utilities](https://www.telerik.com/kendo-react-ui/drag-and-drop)
-   [React Icon & SvgIcon Components](https://www.telerik.com/kendo-react-ui/icon-svgicon)
-   [React Typography Component](https://www.telerik.com/kendo-react-ui/typography)

_Copyright © 2025 Progress Software Corporation and/or its subsidiaries or affiliates. All Rights Reserved._

_Progress, Telerik, and certain product names used herein are trademarks or registered trademarks of Progress Software Corporation and/or one of its subsidiaries or affiliates in the U.S. and/or other countries._
